@@ -1,4 +1,4 @@
-/* xscreensaver, Copyright (c) 2006-2020 Jamie Zawinski <jwz@jwz.org>
+/* xscreensaver, Copyright © 2006-2021 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -14,6 +14,8 @@
 
 #import "InvertedSlider.h"
 
+#ifndef HAVE_TVOS
+
 @implementation InvertedSlider
 
 - (id) initWithFrame:(NSRect)r
@@ -165,3 +167,5 @@
 
 
 @end
+
+#endif // !HAVE_TVOS
