@@ -10,24 +10,11 @@
  * implied warranty.
  */
 
-#include <math.h>
-
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
-
-#include <stdlib.h>
-
-#ifndef HAVE_COCOA
-# include <GL/gl.h>
-#endif
-
-#ifdef HAVE_JWZGLES
-# include "jwzgles.h"
-#endif /* HAVE_JWZGLES */
-
+#include "screenhackI.h"
 #include "tube.h"
 
+#include <math.h>
+
 typedef struct { GLfloat x, y, z; } XYZ;
 
 
